@@ -25,12 +25,18 @@ def unused():
     files = glob(path.join(args.dirname, "*.hst"))
     programs = [Histogram.parse(file, isa=args.isa) for file in files]
 
-    inst_used = set()
+    inst_used, reg_used = set(), set()
     for program in programs:
         # populate inst_used
         inst_used.update(program.getInstructionNameSet())
+        reg_used.update(program.getRegisterSet())
 
-    unused_inst = RV32(isa=args.isa).instructionNameSet - inst_used
+    rv = programs[0].rv
+    unused_inst = rv.instructionNameSet - inst_used
+    unused_reg = rv.registerSet - reg_used
 
     pp = PrettyPrinter(indent=4)
+    print("unused instructions:")
     pp.pprint(unused_inst)
+    print("unused registers:")
+    pp.pprint(unused_reg)
